#!/usr/bin/env python
# coding: utf-8

# In[1]:


import matplotlib.pyplot as plt
import numpy as np
from sklearn import linear_model
import pandas as pd


# In[2]:


reg = linear_model.LinearRegression()


# In[3]:


reg.fit([[0, 0], [1, 1], [2, 2]], [0, 1, 2])


# In[4]:


print(reg.intercept_, reg.coef_)


# In[5]:


df = pd.read_csv("https://www-lisic.univ-littoral.fr/~verel/TEACHING/22-23/apprentissage-automatique-avance-M2/data01/cars.csv")


# In[6]:


df.head()


# In[7]:


df.info()


# In[8]:


# basic descriptive statistics
df.describe()


# In[9]:


# co-variance matrix
np.cov(df.speed, df.dist)


# In[10]:


# co-variance matrix from pandas
df.cov()


# In[11]:


# correlation matrix
df.corr()


# In[12]:


reg_cars = linear_model.LinearRegression()


# In[17]:


#x = [ [x] for x in df.speed ]
X = df.drop(['dist'], axis = 1)
y = np.array(df.dist)


# In[18]:


print(X, y)


# In[19]:


reg_cars.fit(X, y)


# In[20]:


print(reg_cars.intercept_, reg_cars.coef_)
y_pred = reg_cars.predict(X)


# In[22]:


# Plot outputs
plt.scatter(X, y,  color='black')
plt.plot(X, y_pred, color='blue', linewidth=3)

plt.show()


# In[23]:


dfb = pd.read_csv("https://www-lisic.univ-littoral.fr/~verel/TEACHING/22-23/apprentissage-automatique-avance-M2/data01/basketData09.csv", sep = ' ')


# In[24]:


dfb.head()


# In[25]:


dfb.info()


# In[26]:


dfb.describe()


# In[27]:


dfb.corr()


# In[28]:


plt.scatter(dfb.height, dfb.points,  color='black')

plt.show()


# In[29]:


plt.scatter(dfb.weight, dfb.points,  color='blue')

plt.show()


# In[30]:


reg_b = linear_model.LinearRegression()


# In[31]:


#x = [ [x1, x2] for x1, x2 in zip(dfb.weight, dfb.height) ]
X = dfb.drop(['fielGoal', 'freeThrows', 'points'], axis=1)
y = np.array(dfb.points)


# In[32]:


reg_b.fit(X, y)


# In[33]:


y_pred = reg_b.predict(X)


# In[34]:


# Root mean square error of the multilinear model:
np.sqrt(np.mean((y - y_pred)**2))


# In[45]:


# mean absolute error of the multilinear model:
np.mean(np.abs((y - y_pred)))


# In[35]:


print(reg_b.intercept_, reg_b.coef_)

Notice that: increasing the average points decreases with the increasing of the height, and the opposite for weight feature.
But, it is not possible to compare the value of the coefficients directement. They must be rescale.
# In[36]:


from sklearn.preprocessing import StandardScaler
from sklearn.pipeline import Pipeline


# In[37]:


pipe = Pipeline([('scaler', StandardScaler()), ('linear', linear_model.LinearRegression())])


# In[38]:


pipe.fit(X, y)


# In[39]:


y_pred = pipe.predict(X)
print(np.sqrt(np.mean((y - y_pred)**2)))


# In[49]:


plt.scatter(y_pred, y,  color='black')
plt.plot(y_pred, y_pred, color='blue', linewidth=3) # y = x line

plt.show()


# In[40]:


print(pipe[-1].intercept_, pipe[-1].coef_) 

Of course, with a linear transformation of predictors, the quality is exactly the same.
But now, it is possible to fairly compare the value of coefficients.
The variable "height" has nearly the same impact of the prediction than the variable "weight". They only differ from factor of 1 - 0.91628795 / 1.16719321 = 21.5%
# In[41]:


0.91628795 / 1.16719321

Extra: scatterplot matrix of features (pair plot). Have fun with it by modifying the style...
# In[42]:


# see: https://seaborn.pydata.org/generated/seaborn.pairplot.html
import seaborn as sns
sns.pairplot(dfb)


# In[43]:


dfb.hist(bins=50, figsize=(20,15))


# In[44]:


plt.figure(figsize=(14,8))
corr = dfb.corr()
heatmap = sns.heatmap(corr, annot=True, cmap="Blues")


# In[ ]:




